@@ -3,35 +3,8 @@
 # Univention mail Postfix Policy
 #  check allowed email senders for groups and distlist
 #
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
-# Copyright 2005-2024 Univention GmbH
-#
-# https://www.univention.de/
-#
-# All rights reserved.
-#
-# The source code of this program is made available
-# under the terms of the GNU Affero General Public License version 3
-# (GNU AGPL V3) as published by the Free Software Foundation.
-#
-# Binary versions of this program provided by Univention to you as
-# well as other copyrighted, protected or trademarked materials like
-# Logos, graphics, fonts, specific documentations and configurations,
-# cryptographic keys etc. are subject to a license agreement between
-# you and Univention and not subject to the GNU AGPL V3.
-#
-# In the case you use this program under the terms of the GNU AGPL V3,
-# the program is provided in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-# GNU Affero General Public License for more details.
-#
-# You should have received a copy of the GNU Affero General Public
-# License with the Debian GNU/Linux or Univention distribution in file
-# /usr/share/common-licenses/AGPL-3; if not, see
-# <https://www.gnu.org/licenses/>.
+# SPDX-FileCopyrightText: 2005-2025 Univention GmbH
+# SPDX-License-Identifier: AGPL-3.0-only
 
 
 import argparse
@@ -127,10 +100,7 @@ def check_ldap_users_and_groups(sender: str, recipient: str) -> str:
 
     # get dn and groups of sender
     if check_sasl_username:
-        if use_dovecot_sasl:
-            user_filter = filter_format("(uid=%s)", (sender,))
-        else:
-            user_filter = filter_format("(|(uid=%s)(mailPrimaryAddress=%s))", (sender, sender))
+        user_filter = filter_format("(|(uid=%s)(mailPrimaryAddress=%s))", (sender, sender))
     else:
         user_filter = filter_format(
             "(|(mailPrimaryAddress=%s)(mailAlternativeAddress=%s)(mail=%s))",
